QC Dashboard - person_poor.yaml

### Global Compliance

12.5%
1/8 fields populated

### Weighted Compliance

25.0%
Based on configured weights

### Threshold Violations

0
All thresholds met

### Recommended Slots

4
Tracked across schema

## Overall Compliance

## Compliance by Slot

## Path × Slot Heatmap

## Threshold Violations

No threshold violations detected.

## Slot Compliance Details

Slot | Compliance | Progress
--- | --- | ---
`description` | 0.0% |
`street` | 0.0% |
`city` | 0.0% |
`email` | 33.3% |